@@ -13,10 +13,10 @@
 ##############################################################################
 """Mail delivery names vocabulary test
 
-$Id: test_vocabulary.py 69432 2006-08-12 17:36:18Z philikon $
+$Id: test_vocabulary.py 106772 2009-12-18 20:27:54Z kobold $
 """
 import unittest
-from zope.testing.doctestunit import DocTestSuite
+from zope.testing.doctest import DocTestSuite
 from zope.component.testing import setUp, tearDown
 
 def test_suite():
